@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Itself ;
-$Config::Model::Itself::VERSION = '2.009';
+$Config::Model::Itself::VERSION = '2.010';
 use Mouse ;
 use Config::Model 2.101;
 use 5.010;
@@ -283,7 +283,7 @@ sub read_all {
 
         # @models order is important to write configuration class back in the same
         # order as the declaration
-        my @models = $tmp_model -> load ( 'Tmp' , $file ) ;
+        my @models = $tmp_model -> load ( 'Tmp' , $file->absolute ) ;
         push @all_models, @models;
 
         my $rel_file = $file ;
@@ -765,7 +765,7 @@ Config::Model::Itself - Model editor for Config::Model
 
 =head1 VERSION
 
-version 2.009
+version 2.010
 
 =head1 SYNOPSIS
 
